@@ -260,14 +260,13 @@ flames_get_flat_size(
     float y_upp_min =0;
     float y_upp_max =0;
 
-    int ycTracePix=0;                   /* central Y pos of trace Yc(Xc,Mc) */
+
 
 
     double tmpFct=0;                     /* tmp variable */
 
 
 
-    double yShift=0;                     /* shift of order trace respect to Yc */
 
     int SF = 0;                         /* alias for short float */
     int i  = 0;                         /* loop index */
@@ -486,7 +485,8 @@ flames_get_flat_size(
       printf("%f\n",ycTrace); 
          */
         double tmp =  rint(ycTrace);
-        ycTracePix = (int) tmp;
+        /* central Y pos of trace Yc(Xc,Mc) */
+        int ycTracePix = (int) tmp;
 
         /*
       printf("ycTracePix=%i\n",ycTracePix);
@@ -697,7 +697,8 @@ flames_get_flat_size(
         double ycSlitPix=(yMin+yMax)/2.;
         double disTraceYmin=(ycTrace-yMin);
         double disTraceYmax=(yMax-ycTrace);
-        yShift=-(ycTrace-ycSlitPix);
+        /* shift of order trace respect to Yc */
+        double yShift=-(ycTrace-ycSlitPix);
         double halfWidth=(yMax-yMin)/2.;
 
         sto_y_shift[ord]=yShift;
