@@ -1,3 +1,5 @@
+from __future__ import absolute_import
+from __future__ import print_function
 def log_invocation(fn='/tmp/reflex_invoc.log'):
     """ log invocation of actor for easy reexecution with:
         eval $(cat /tmp/reflex_invoc.log)
@@ -138,11 +140,11 @@ try:
           nfl = list_hdus_sci_redl[0].data.shape[0]
           nfu = list_hdus_sci_redu[0].data.shape[0]
           self.cubify = True
-          print "Sci Fibre cube format"
+          print("Sci Fibre cube format")
       else :
           nfl = len(list_sci_redl)
           nfu = len(list_sci_redu)
-          print "Sci fibre normal format"
+          print("Sci fibre normal format")
       
       #print "nf=", nf , "cubify = ", self.cubify
 
@@ -190,7 +192,7 @@ try:
         #table=list_hdus_sci_info_tab_redl[0].data[i,:]
         self.red_sci_point_mos_found = True
         if self.cubify == True :
-           print "cube case"
+           print("cube case")
            #import pdb
            #pdb.set_trace()
            self.list_spec_raw.append(UvesRedSpectrum(list_hdus_sci_redl[0].data[i,:],list_hdus_sci_redu[0].data[i,:],list_hdus_err_sci_redl[0].data[i,:],list_hdus_err_sci_redu[0].data[i,:]))
@@ -379,7 +381,8 @@ For Red data:  PRO.CATG=MWXB_SCI_REDL, MWXB_SCI_REDU"""
 #      paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='drs_base_name',group='general',description="""Base name for science products. [fxb]"""))
       paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='drs_maxyshift',group='extract',description="""Half width of the interval to scan for correlation, when determining y shift. [3.0]"""))
       paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='drs_ext_w_siz',group='extract',description="""Integration window size good: 10 (if fibre deconvolution works fine). [10.0]"""))
-      paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='rebin.wavestep',group='rebin',description="""The bin size (in w.l.u.) in wavelength space. If negative, a step size of 2/3 * ( average pixel size ) is used. [-1.0]"""))
+      paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='rebin.wavestep',group='rebin',description="""The bin size used for BLUE/REDL data (in w.l.u.) in wavelength space. If negative, a step size of 2/3 * ( average pixel size ) is used. [-1.0]"""))
+      paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='rebin.wavestep_redu',group='rebin',description="""The bin size used for REDU data (in w.l.u.) in wavelength space. If negative, a step size of 2/3 * ( average pixel size ) is used. [-1.0]"""))
       paramList.append(RecipeParameter(recipe='flames_obs_scired',displayName='rebin.scale',group='rebin',
       description="""Whether
       or not to multiply by the factor dx/dlambda (pixels per
@@ -426,7 +429,7 @@ Attempt to optimise the S/N of the extracted spectrum as a function of spectral
 
 except ImportError:
   import_sucess = 'false'
-  print "Error importing modules pyfits, wx, matplotlib, numpy"
+  print("Error importing modules pyfits, wx, matplotlib, numpy")
 
 #This is the 'main' function
 if __name__ == '__main__':
