@@ -20,147 +20,6 @@
 /*
  * $Author: amodigli $
  * $Date: 2010-09-24 09:32:07 $
- * $Revision: 1.47 $
- * $Name: not supported by cvs2svn $
- * $Log: not supported by cvs2svn $
- * Revision 1.45  2010/06/09 07:17:14  amodigli
- * renamed parameter definition function used by response step in redchain recipe to make them more explicit
- *
- * Revision 1.44  2010/06/08 16:30:18  amodigli
- * Fixed problems in parameter definition for reduction chain recipe
- *
- * Revision 1.43  2010/04/28 08:48:23  amodigli
- * use uves_define_efficiency_parameters()
- *
- * Revision 1.42  2008/09/29 06:59:16  amodigli
- * add #include <string.h>
- *
- * Revision 1.41  2008/03/28 08:54:27  amodigli
- * IRPLIB_CONCAT2X-->UVES_CONCAT2X
- *
- * Revision 1.40  2008/02/15 12:43:49  amodigli
- * allow lower/upper chip for parameter process_chip
- *
- * Revision 1.39  2007/11/13 16:19:55  amodigli
- * adding DATAMD5 to calib products
- *
- * Revision 1.38  2007/10/05 16:01:45  amodigli
- * using proces_chip parameter to process or not a given RED chip
- *
- * Revision 1.37  2007/08/21 13:08:26  jmlarsen
- * Removed irplib_access module, largely deprecated by CPL-4
- *
- * Revision 1.36  2007/06/28 09:19:24  jmlarsen
- * Do not compute master dark if provided
- *
- * Revision 1.35  2007/06/11 13:28:26  jmlarsen
- * Changed recipe contact address to cpl at eso.org
- *
- * Revision 1.34  2007/06/08 13:06:16  jmlarsen
- * Send bug reports to Andrea
- *
- * Revision 1.33  2007/06/06 08:17:33  amodigli
- * replace tab with 4 spaces
- *
- * Revision 1.32  2007/05/22 09:11:06  jmlarsen
- * Reverse logic bugfix
- *
- * Revision 1.31  2007/05/22 08:13:19  amodigli
- * allow to process only blu or red data
- *
- * Revision 1.30  2007/05/14 08:09:48  amodigli
- * updated input frames and tag description in recipe man page
- *
- * Revision 1.29  2007/05/03 16:03:58  jmlarsen
- * uves_obs_redchain: Implemented option to skip final science reduction
- *
- * Revision 1.28  2007/02/09 13:40:26  jmlarsen
- * Use defines for recipe id
- *
- * Revision 1.27  2007/02/09 08:58:51  jmlarsen
- * Use define's rather than hard-coded recipe names
- *
- * Revision 1.26  2006/11/24 16:21:39  jmlarsen
- * Added FIB_LINE_TABLE_x
- *
- * Revision 1.25  2006/11/15 15:02:15  jmlarsen
- * Implemented const safe workarounds for CPL functions
- *
- * Revision 1.23  2006/11/15 14:04:08  jmlarsen
- * Removed non-const version of parameterlist_get_first/last/next which is
- * already in CPL, added const-safe wrapper, unwrapper and deallocator functions
- *
- * Revision 1.22  2006/11/13 12:47:08  jmlarsen
- * Changed syntax of UVES_ARC_LAMP to support FLAMES
- *
- * Revision 1.21  2006/11/06 15:19:41  jmlarsen
- * Removed unused include directives
- *
- * Revision 1.20  2006/10/24 14:06:27  jmlarsen
- * Added flames=false where relevant
- *
- * Revision 1.19  2006/10/19 13:53:25  jmlarsen
- * Changed guess line table tag to LINE_GUESS_TAB
- *
- * Revision 1.18  2006/10/17 12:33:02  jmlarsen
- * Added semicolon at UVES_RECIPE_DEFINE invocation
- *
- * Revision 1.17  2006/10/09 13:01:13  jmlarsen
- * Use macro to define recipe interface functions
- *
- * Revision 1.16  2006/10/02 08:37:49  jmlarsen
- * Added REF_TFLAT
- *
- * Revision 1.15  2006/09/27 15:08:45  jmlarsen
- * Fixed doc. bug
- *
- * Revision 1.14  2006/09/14 08:46:51  jmlarsen
- * Added support for TFLAT, SCREEN_FLAT frames
- *
- * Revision 1.13  2006/08/17 13:56:53  jmlarsen
- * Reduced max line length
- *
- * Revision 1.12  2006/08/16 11:58:02  jmlarsen
- * Fixed trivial but harmful buffer overrun
- *
- * Revision 1.11  2006/08/11 14:56:05  amodigli
- * removed Doxygen warnings
- *
- * Revision 1.10  2006/07/14 12:30:34  jmlarsen
- * Compute PRO CATG depending on DO CATG
- *
- * Revision 1.9  2006/07/03 13:27:10  jmlarsen
- * Minor doc update
- *
- * Revision 1.8  2006/07/03 13:16:47  amodigli
- * updated description
- *
- * Revision 1.7  2006/06/16 08:25:45  jmlarsen
- * Manually propagate ESO.DET. keywords from 1st/2nd input header
- *
- * Revision 1.6  2006/06/13 12:00:54  jmlarsen
- * Support ORDER_GUESS_TAB
- *
- * Revision 1.5  2006/04/24 09:23:33  jmlarsen
- * Recognize PDARK, DFLAT, IFLAT as products
- *
- * Revision 1.4  2006/04/06 12:56:50  jmlarsen
- * Added support for PDARK, IFLAT, DLFAT frames
- *
- * Revision 1.3  2006/04/06 11:48:17  jmlarsen
- * Support for SCI_POINT_-, SCI_EXTND_- and SCI_SLICER-frames
- *
- * Revision 1.2  2006/04/06 08:47:16  jmlarsen
- * Support DFLAT, IFLAT, PDARK
- *
- * Revision 1.1  2006/02/03 07:46:30  jmlarsen
- * Moved recipe implementations to ./uves directory
- *
- * Revision 1.14  2006/01/19 08:47:24  jmlarsen
- * Inserted missing doxygen end tag
- *
- * Revision 1.13  2005/12/20 08:11:44  jmlarsen
- * Added CVS  entry
  *
  */
 
@@ -436,13 +295,13 @@ UVES_CONCAT2X(UVES_REDCHAIN_ID,exe)(cpl_frameset *frames,
     /* Split in blue/red frames */
     {
         cpl_frame *f = NULL;
-
-        for (f = cpl_frameset_get_first(frames);
-             f != NULL;
-             f = cpl_frameset_get_next(frames))
+        int i=0;
+        int nfrm=0;
+        nfrm=cpl_frameset_get_size(frames);
+        for (i=0;i<nfrm;i++)
             {
 
-
+                f=cpl_frameset_get_frame(frames,i);
                 if (frame_is_needed(true, f))    /* Used in blue arm? */
                     {
                         uves_msg_debug("Found blue frame: '%s'", cpl_frame_get_tag(f));
@@ -468,12 +327,14 @@ UVES_CONCAT2X(UVES_REDCHAIN_ID,exe)(cpl_frameset *frames,
                     }
 
             }
-
         /* Remove all frames from input frame set */
-        while ((f = cpl_frameset_get_first(frames)) != NULL)
-            {
-                cpl_frameset_erase_frame(frames, f);
-            }
+        cpl_frame *frm = NULL;
+        for (i=0;i<nfrm;i++) {
+            check_nomsg(frm=cpl_frameset_get_frame(frames,0));
+            check_nomsg(cpl_frameset_erase_frame(frames, frm));
+        }
+
+
     }
 
     /* Algorithm:
@@ -917,11 +778,12 @@ UVES_CONCAT2X(UVES_REDCHAIN_ID,exe)(cpl_frameset *frames,
             /* Insert all product frames into recipe frame set */
             {
                 cpl_frame *f = NULL;
-                
-                for (f = cpl_frameset_get_first(fms);
-                     f != NULL;
-                     f = cpl_frameset_get_next(fms))
+                int i=0;
+                int nfrm=0;
+                nfrm=cpl_frameset_get_size(fms);
+                for (i=0;i<nfrm;i++)
                     {
+                     f=cpl_frameset_get_frame(fms,i);
                         if (cpl_frame_get_group(f) == CPL_FRAME_GROUP_PRODUCT)
                             {
                                 check( cpl_frameset_insert(frames, cpl_frame_duplicate(f)),
@@ -1062,10 +924,11 @@ execute_recipe(const char *recipe_id,
           for (i = 0; i < n_products; i++)
               {
                   cpl_frame *found = NULL;
-                  for (f = cpl_frameset_get_first(frames);
-                       f != NULL;
-                       f = cpl_frameset_get_next(frames))
+                  int j=0;
+                  int nfrm=cpl_frameset_get_size(frames);
+                  for (j=0;j<nfrm;j++)
                       {
+                          f=cpl_frameset_get_frame(frames,j);
                           if (cpl_frame_get_group(f) == CPL_FRAME_GROUP_PRODUCT)
                               {
                                   if (strcmp(cpl_frame_get_tag(f), products[i]) == 0)
@@ -1089,10 +952,14 @@ execute_recipe(const char *recipe_id,
            * Remove other products that 
            * are not used later  (e.g. BKG_FLAT_xxxx)
            */
-          for (f = cpl_frameset_get_first(frames);
-               f != NULL;
-               f = cpl_frameset_get_next(frames))
+
+          int k=0;
+          int nfrm=cpl_frameset_get_size(frames);
+          int nerased=0;
+          for (k=0;k<nfrm-nerased;k++)
               {
+                  f=cpl_frameset_get_frame(frames,k);
+
                   if (cpl_frame_get_group(f) == CPL_FRAME_GROUP_PRODUCT)
                       {
                           /* Remove this product */
@@ -1101,9 +968,11 @@ execute_recipe(const char *recipe_id,
                                    cpl_frame_get_tag(f), cpl_frame_get_filename(f));
                           
                           cpl_frameset_erase_frame(frames, f);
-                          
+                          nerased++;
+
                       }
               }  
+
       } /* if re-classify... */  
 
   cleanup:
