@@ -379,7 +379,7 @@ uves_mflat_process_chip(const cpl_imagelist *raw_images,
     {
         uves_msg("Skipping background subtraction");
     }
-    uves_pfits_set_extname(master_flat_header,"Master flat");
+    //uves_pfits_set_extname(master_flat_header,"Master flat");
   cleanup:
 
 
@@ -940,8 +940,7 @@ uves_reduce_mflat(cpl_frameset *frames, const cpl_parameterlist *parameters,
                "Error getting filename");
             strcpy(pro_filename,prefix);
             strcat(pro_filename,product_filename);
-            uves_pfits_set_extname(product_header[raw_index],
-                                   "Inter-order background");
+            //uves_pfits_set_extname(product_header[raw_index],"Inter-order background");
             check( uves_frameset_insert(frames,
                         background,
                         CPL_FRAME_GROUP_PRODUCT,
